@@ -77,14 +77,6 @@ class Document(metaclass=MetaDocument):
         super().__setattr__("_document_", DocumentDict(kwargs))
         super().__setattr__("shadow_copy", DocumentDict(kwargs.copy()))
 
-    @classmethod
-    async def _async_init(cls, **kwargs):
-
-        document_in_database = await cls._collection().find_one(kwargs)
-        if not document_in_database:
-            raise DocumentDoesntExist()
-        return cls(**document_in_database)
-
     def __repr__(self):
         return "{0}({1})".format(
             self.__class__.__name__,
@@ -172,8 +164,9 @@ class Document(metaclass=MetaDocument):
         """Finds one document based on kwargs."""
 
         document = await cls._collection().find_one(kwargs)
-        document = document if document else {}
-        return await cls._async_init(**document)
+        if not document:
+            raise DocumentDoesntExist()
+        return cls(**document)
 
     @classmethod
     @check_setup
@@ -183,7 +176,7 @@ class Document(metaclass=MetaDocument):
         result_list = []
         cursor = cls._collection().find(kwargs)
         async for doc in cursor:
-            result_list.append(await cls._async_init(**doc))
+            result_list.append(cls(**doc))
         return result_list
 
     @classmethod
@@ -192,7 +185,7 @@ class Document(metaclass=MetaDocument):
         """Create new document."""
 
         await cls._collection().insert_one(kwargs)
-        return await cls._async_init(_id=kwargs["_id"])
+        return cls(**kwargs)
 
 
     async def _delete_by_prop(self, relations):
